| Title: | Dynamic Panel Threshold Model |
|---|---|
| Description: | Compute the dynamic threshold panel model suggested by (Stephanie Kremer, Alexander Bick and Dieter Nautz (2013) <doi:10.1007/s00181-012-0553-9>) in which they extended the (Hansen (1999) <doi: 10.1016/S0304-4076(99)00025-1>) original static panel threshold estimation and the Caner and (Hansen (2004) <doi:10.1017/S0266466604205011>) cross-sectional instrumental variable threshold model, where generalized methods of moments type estimators are used. |
| Authors: | Taha Zaghdoudi |
| Maintainer: | Taha Zaghdoudi <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.0 |
| Built: | 2026-05-24 09:35:24 UTC |
| Source: | https://github.com/cran/dtp |
Dynamic threshold panel function
dtp(f, data, index = c("state", "year"), maxlags, initnum, conf, conf1, conf2, graph = TRUE)dtp(f, data, index = c("state", "year"), maxlags, initnum, conf, conf1, conf2, graph = TRUE)
f |
the formula |
data |
the dataframe |
index |
c=("id","time") |
maxlags |
the instruments maximum lags number |
initnum |
column number of the initial variable |
conf |
the confidential interval |
conf1 |
the confidential interval |
conf2 |
the confidential interval |
graph |
TRUE to show the threshold plot |
############################################ # Fit the dynamic threshold panel data ############################################ # Load data data(Mena) ############################################ # Estimate the model ############################################ reg<-dtp(GDPPC ~ FDI+OPEN|INF|INF,Mena,index=c("pays","ann"),4,2,0.95,0.8,1,graph = TRUE) summary(reg)############################################ # Fit the dynamic threshold panel data ############################################ # Load data data(Mena) ############################################ # Estimate the model ############################################ reg<-dtp(GDPPC ~ FDI+OPEN|INF|INF,Mena,index=c("pays","ann"),4,2,0.95,0.8,1,graph = TRUE) summary(reg)
The data frame Mena contains the following variables:
pays:the countries
ann:the year
GDPPC:GDP per capita growth (annual pourcentage)
FDI:Foreign direct investment, net inflows (pourcentageof GDP)
INF:Inflation, consumer prices (annual pourcentage)
OPEN:public capital
data(Mena)data(Mena)
A data frame with 274 rows and 4 variables
summary method for a dtp model.
## S3 method for class 'dtp' summary(object, ...)## S3 method for class 'dtp' summary(object, ...)
object |
is the object of the function |
... |
not used |
an object of the S3 class summary.dtp with the
following components: